import { extent } from 'd3';
import { eachHourOfInterval, startOfDay, endOfDay } from 'date-fns';
export function createXAxisLabel(bin) {
    return `Bin ${bin + 1}`;
}
export function getDayData(data) {
    const binCountPerHour = Math.ceil((data.details?.length ?? 0) / 24);
    const dataArray = data.details
        ?.sort((a, b) => new Date(a.date).getTime() - new Date(b.date).getTime())
        .map((e, idx) => {
        const date = new Date(e.date);
        return {
            date,
            col: idx % binCountPerHour,
            hour: date.getHours(),
            value: e.value,
        };
    }) ?? [];
    const [minValue, maxValue] = extent(dataArray, (d) => d.value);
    return {
        dataArray,
        valueExtent: [minValue ?? NaN, maxValue ?? NaN],
    };
}
function convertDatetoYAxisLabel(date) {
    return date.toLocaleString(undefined, { hour12: true, hour: '2-digit' });
}
export function generateYAxisLabels() {
    const today = new Date();
    const startOfToday = startOfDay(today);
    const endOfToday = endOfDay(today);
    const labels = eachHourOfInterval({
        start: startOfToday,
        end: endOfToday,
    }).map((date) => convertDatetoYAxisLabel(date));
    return labels;
}
//# sourceMappingURL=utils.js.map