import { rollup, sum, extent, range } from 'd3';
export function getGlobalHeatmapCellDimensions(element, xScale, margin) {
    const { clientHeight } = element;
    const width = xScale.bandwidth();
    let height = clientHeight - margin.top - margin.bottom;
    height = height > 0 ? height : 0;
    return [width, height];
}
export function getGlobalData(data) {
    let dataArray = [];
    let minTotal;
    let maxTotal;
    let minYear;
    let maxYear;
    if (data.length > 0) {
        const groupedData = rollup(data, (g) => sum(g, (d) => d.total), (d) => new Date(d.date).getFullYear());
        const yearsPresent = Array.from(groupedData.keys());
        [minYear, maxYear] = extent(yearsPresent);
        minYear = minYear ?? NaN;
        maxYear = maxYear ?? NaN;
        const consecutiveYears = range(minYear, maxYear + 1);
        const consecutiveYearsMap = consecutiveYears.reduce((acc, curr) => {
            acc.set(curr, NaN);
            return acc;
        }, new Map());
        const combinedData = new Map([...consecutiveYearsMap, ...groupedData]);
        const yearTotalDataArray = Array.from(combinedData);
        dataArray = yearTotalDataArray.map((ele) => ({
            year: ele[0],
            total: ele[1],
        }));
        [minTotal, maxTotal] = extent(dataArray, (d) => d.total);
    }
    return {
        dataArray,
        yearExtent: [minYear ?? NaN, maxYear ?? NaN],
        totalExtent: [minTotal ?? NaN, maxTotal ?? NaN],
    };
}
//# sourceMappingURL=utils.js.map