import { extent, timeDays } from 'd3';
import { endOfMonth, startOfMonth, format } from 'date-fns';
import { removeLastYearWeekData } from '../utils';
export function getWeekLabel(week) {
    return `Week ${week}`;
}
export function getMonthData(data) {
    let dataArray = [];
    let minTotal;
    let maxTotal;
    if (data.length > 0) {
        const dataRecord = data.reduce((acc, curr) => ({
            ...acc,
            [new Date(curr.date).getDate().toString()]: curr,
        }), {});
        const selectedDate = new Date(data[0].date);
        const minDate = startOfMonth(selectedDate);
        const maxDate = endOfMonth(selectedDate);
        const consecutiveDates = timeDays(minDate, maxDate);
        const consecutiveDatesRecord = consecutiveDates.reduce((acc, curr) => ({
            ...acc,
            [curr.getDate().toString()]: {
                date: curr.toISOString(),
                total: NaN,
            },
        }), {});
        const combinedData = { ...consecutiveDatesRecord, ...dataRecord };
        dataArray = Object.values(combinedData).map((d) => {
            const date = new Date(d.date);
            return {
                day: Number.parseInt(format(date, 'i'), 10),
                week: Number.parseInt(format(date, 'I'), 10),
                total: d.total,
                date,
            };
        });
        if (format(selectedDate, 'M') === '1') {
            dataArray = removeLastYearWeekData(dataArray);
        }
        [minTotal, maxTotal] = extent(dataArray, (d) => d.total);
    }
    return { dataArray, totalExtent: [minTotal ?? NaN, maxTotal ?? NaN] };
}
//# sourceMappingURL=utils.js.map